This is an automated email from the ASF dual-hosted git repository.
davidb pushed a commit to branch master
in repository
https://gitbox.apache.org/repos/asf/sling-org-apache-sling-feature-analyser.git
The following commit(s) were added to refs/heads/master by this push:
new d80bf25 Add some missing Javadoc
d80bf25 is described below
commit d80bf2528ff54cd701824b6199d1fabaf01a7a19
Author: David Bosschaert <[email protected]>
AuthorDate: Sat May 5 20:24:21 2018 +0100
Add some missing Javadoc
---
.../apache/sling/feature/analyser/task/AnalyserTask.java | 12 +++++++++---
.../sling/feature/analyser/task/AnalyserTaskContext.java | 3 ++-
.../java/org/apache/sling/feature/scanner/Scanner.java | 15 +++++++--------
.../sling/feature/scanner/spi/ExtensionScanner.java | 12 ++++++++----
.../sling/feature/scanner/spi/FrameworkScanner.java | 10 +++++-----
5 files changed, 31 insertions(+), 21 deletions(-)
diff --git
a/src/main/java/org/apache/sling/feature/analyser/task/AnalyserTask.java
b/src/main/java/org/apache/sling/feature/analyser/task/AnalyserTask.java
index 97cd99a..e0db1e1 100644
--- a/src/main/java/org/apache/sling/feature/analyser/task/AnalyserTask.java
+++ b/src/main/java/org/apache/sling/feature/analyser/task/AnalyserTask.java
@@ -25,17 +25,23 @@ import org.osgi.annotation.versioning.ConsumerType;
@ConsumerType
public interface AnalyserTask {
- /** A unique (short) id. */
+ /** A unique (short) ID.
+ * @return the task ID.
+ */
default String getId() {
return getClass().getName();
};
- /** A human readable name to identify the task. */
+ /** A human readable name to identify the task.
+ * @return the task name.
+ */
default String getName() {
return getClass().getSimpleName();
};
- /** Execute the task. */
+ /** Execute the task.
+ * @param the task context.
+ */
void execute(AnalyserTaskContext ctx) throws Exception;
}
diff --git
a/src/main/java/org/apache/sling/feature/analyser/task/AnalyserTaskContext.java
b/src/main/java/org/apache/sling/feature/analyser/task/AnalyserTaskContext.java
index b33fd80..0eb2a9d 100644
---
a/src/main/java/org/apache/sling/feature/analyser/task/AnalyserTaskContext.java
+++
b/src/main/java/org/apache/sling/feature/analyser/task/AnalyserTaskContext.java
@@ -30,7 +30,8 @@ public interface AnalyserTaskContext {
Application getApplication();
/**
- * The application descriptor
+ * The application descriptor.
+ * @return the descriptor.
*/
ApplicationDescriptor getDescriptor();
diff --git a/src/main/java/org/apache/sling/feature/scanner/Scanner.java
b/src/main/java/org/apache/sling/feature/scanner/Scanner.java
index b0c29a9..4d818ee 100644
--- a/src/main/java/org/apache/sling/feature/scanner/Scanner.java
+++ b/src/main/java/org/apache/sling/feature/scanner/Scanner.java
@@ -16,13 +16,6 @@
*/
package org.apache.sling.feature.scanner;
-import java.io.File;
-import java.io.IOException;
-import java.util.ArrayList;
-import java.util.List;
-import java.util.Map;
-import java.util.ServiceLoader;
-
import org.apache.sling.feature.Application;
import org.apache.sling.feature.Artifact;
import org.apache.sling.feature.Bundles;
@@ -37,6 +30,13 @@ import
org.apache.sling.feature.scanner.impl.FeatureDescriptorImpl;
import org.apache.sling.feature.scanner.spi.ExtensionScanner;
import org.apache.sling.feature.scanner.spi.FrameworkScanner;
+import java.io.File;
+import java.io.IOException;
+import java.util.ArrayList;
+import java.util.List;
+import java.util.Map;
+import java.util.ServiceLoader;
+
/**
* The scanner is a service that scans items and provides descriptions for
these.
* The following items can be scanned individually
@@ -60,7 +60,6 @@ public class Scanner {
* Create a new scanner
*
* @param amConfig The artifact manager configuration
- * @param artifactScanners A list of artifact scanners
* @param extensionScanners A list of extension scanners
* @param frameworkScanners A list of framework scanners
* @throws IOException If something goes wrong
diff --git
a/src/main/java/org/apache/sling/feature/scanner/spi/ExtensionScanner.java
b/src/main/java/org/apache/sling/feature/scanner/spi/ExtensionScanner.java
index 773f210..1e8e7de 100644
--- a/src/main/java/org/apache/sling/feature/scanner/spi/ExtensionScanner.java
+++ b/src/main/java/org/apache/sling/feature/scanner/spi/ExtensionScanner.java
@@ -16,23 +16,27 @@
*/
package org.apache.sling.feature.scanner.spi;
-import java.io.IOException;
-
import org.apache.sling.feature.Extension;
import org.apache.sling.feature.io.ArtifactManager;
import org.apache.sling.feature.scanner.ContainerDescriptor;
import org.osgi.annotation.versioning.ConsumerType;
+import java.io.IOException;
+
/**
* The extension scanner scans an extension.
*/
@ConsumerType
public interface ExtensionScanner {
- /** A unique (short) id. */
+ /** A unique (short) ID.
+ * @return the ID.
+ */
String getId();
- /** A human readable name to identify the scanner. */
+ /** A human readable name to identify the scanner.
+ * @return the name.
+ */
String getName();
/**
diff --git
a/src/main/java/org/apache/sling/feature/scanner/spi/FrameworkScanner.java
b/src/main/java/org/apache/sling/feature/scanner/spi/FrameworkScanner.java
index fcfc0ef..80cf132 100644
--- a/src/main/java/org/apache/sling/feature/scanner/spi/FrameworkScanner.java
+++ b/src/main/java/org/apache/sling/feature/scanner/spi/FrameworkScanner.java
@@ -16,14 +16,14 @@
*/
package org.apache.sling.feature.scanner.spi;
-import java.io.File;
-import java.io.IOException;
-
import org.apache.sling.feature.ArtifactId;
import org.apache.sling.feature.KeyValueMap;
import org.apache.sling.feature.scanner.BundleDescriptor;
import org.osgi.annotation.versioning.ConsumerType;
+import java.io.File;
+import java.io.IOException;
+
/**
* The framework scanner scans the framework
*/
@@ -33,12 +33,12 @@ public interface FrameworkScanner {
/**
* Try to scan the artifact
* @param framework The framework artifact id
* @param file The framework artifact
* @param frameworkProps framework properties to launch the framework
* @return A descriptor or {@code null}
* @throws IOException If an error occurs while scanning the platform or
the artifact is invalid
*/
BundleDescriptor scan(ArtifactId framework,
- File platformFile,
+ File frameworkFile,
KeyValueMap frameworkProps) throws IOException;
}
\ No newline at end of file
@@ -33,12 +33,12 @@ public interface FrameworkScanner {
* Try to scan the artifact
* @param framework The framework artifact id
- * @param file The framework artifact
+ * @param frameworkFile The framework artifact
* @param frameworkProps framework properties to launch the framework
* @return A descriptor or {@code null}
--
To stop receiving notification emails like this one, please contact
[email protected].